<?php
	/**
	 * Exam API client for Loorex.com.<br>
	 *
	 * @author   	loorex.com <support@loorex.com>
	 * @category 	API
	 * @version		1.0
	 * @since		06.03.2019
	 * @package		LoorexApi
	 * @link		http://loorex.com/docs/api/exam.html
	 */

	define("_LOOREX_QT_SINGLECHOICE",		1);
	define("_LOOREX_QT_MULTISELECT",		2);
	define("_LOOREX_QT_TEXT_SIMILARITY",	7);

	class LoorexApiExam extends LoorexApiBase {

		function __construct($accessToken) {
			parent::__construct($accessToken);
		}

		public function examList($params = []) {
			return $this->sendMessage('examList', $params);
		}

		public function examGet($examId) {
			return $this->sendMessage('examGet', ['id'=>$examId]);
		}

		public function examCreate($params) {
			$ret = $this->sendMessage('examCreate', $params);
			return (($ret['id']) ? $ret['id'] : false);
		}

		public function examUpdate($params) {
			$ret = $this->sendMessage('examUpdate', $params);
			return (($ret['completed']) ? true : false);
		}

		public function examUpdateStatus($examId, $ready, $ignoreWarnings = false) {
			$ret = $this->sendMessage('examUpdateStatus', ['id'=>$examId,'ready'=>(($ready) ? true : false),'ignore_warnings'=>$ignoreWarnings]);
			return (($ret['completed']) ? true : false);
		}

		public function examDelete($examId) {
			$ret = $this->sendMessage('examDelete', ['id'=>$examId]);
			return (($ret['completed']) ? true : false);
		}

		public function caseStudyList($examId) {
			return $this->sendMessage('caseStudyList', ['test_id'=>$examId]);
		}

		public function caseStudyGet($examId, $caseStudyId) {
			return $this->sendMessage('caseStudyGet', ['id'=>$caseStudyId,'test_id'=>$examId]);
		}

		public function caseStudyCreate($params) {
			$ret = $this->sendMessage('caseStudyCreate', $params);
			$ret = (($ret['completed'] && $ret['case_study']['id']) ? $ret['case_study']['id'] : false);
			return $ret;
		}

		public function caseStudyUpdate($params) {
			$ret = $this->sendMessage('caseStudyUpdate', $params);
			$ret = (($ret['completed'] && $ret['case_study']['id']) ? true : false);
			return $ret;
		}

		public function caseStudyDelete($examId, $caseStudyId) {
			$ret = $this->sendMessage('caseStudyDelete', ['id'=>$caseStudyId,'test_id'=>$examId]);
			return (($ret['completed']) ? true : false);
		}

		public function questionList($examId) {
			return $this->sendMessage('questionList', ['test_id'=>$examId]);
		}

		public function questionGet($examId, $questionId) {
			return $this->sendMessage('questionGet', ['id'=>$questionId,'test_id'=>$examId]);
		}

		public function questionCreate($params) {
			$ret = $this->sendMessage('questionCreate', $params);
			$ret = (($ret['completed'] && $ret['question']['id']) ? $ret['question']['id'] : false);
			return $ret;
		}

		public function questionUpdate($params) {
			$ret = $this->sendMessage('questionUpdate', $params);
			$ret = (($ret['completed'] && $ret['question']['id']) ? true : false);
			return $ret;
		}

		public function questionDelete($examId, $questionId) {
			$ret = $this->sendMessage('questionDelete', ['id'=>$questionId,'test_id'=>$examId]);
			return (($ret['completed']) ? true : false);
		}

		protected function getApiName() {
			return 'exam';
		}
	}
?>